@@ -30,7 +30,7 @@ getsybilenv <- function(part) {
     printsolvers <- function() {
         cat("\n# --------------------------------------------------------- #\n")
         cat("solver packages:\n")
-        cat(paste(sybil:::.SYBILenv[["solvers"]]), sep = ", ")
+        cat(paste(.SYBILenv[["solvers"]]), sep = ", ")
         cat("\n\n")
     }
 
@@ -40,10 +40,10 @@ getsybilenv <- function(part) {
     printmethods <- function() {
         cat("\n# --------------------------------------------------------- #\n")
         cat("methods included in the solver packages:\n")
-        slv <- names(sybil:::.SYBILenv[["solverMethods"]])
+        slv <- names(.SYBILenv[["solverMethods"]])
         for(i in seq(along = slv)) {
             cat(slv[i], ":\n", sep = "")
-            cat(paste(sybil:::.SYBILenv[["solverMethods"]][[slv[i]]]), sep = ", ")
+            cat(paste(.SYBILenv[["solverMethods"]][[slv[i]]]), sep = ", ")
             cat("\n\n")
         }
         cat("\n")
@@ -55,13 +55,13 @@ getsybilenv <- function(part) {
     printptype <- function() {
         cat("\n# --------------------------------------------------------- #\n")
         cat("methods used for problem types:\n")
-        ptype <- names(sybil:::.SYBILenv[["ptype"]])
+        ptype <- names(.SYBILenv[["ptype"]])
         for(i in seq(along = ptype)) {
             cat(ptype[i], ":\n", sep = "")
-            slv <- names(sybil:::.SYBILenv[["ptype"]][[ptype[i]]])
+            slv <- names(.SYBILenv[["ptype"]][[ptype[i]]])
             for(j in seq(along = slv)) {
                 cat("    ", slv[j], ":\n    ", sep = "")
-                cat(paste(sybil:::.SYBILenv[["ptype"]][[ptype[i]]][[slv[j]]]), sep = ", ")
+                cat(paste(.SYBILenv[["ptype"]][[ptype[i]]][[slv[j]]]), sep = ", ")
                 cat("\n\n")
             }
         }
@@ -74,10 +74,10 @@ getsybilenv <- function(part) {
     printpurpose <- function() {
         cat("\n# --------------------------------------------------------- #\n")
         cat("algorithms for this purpose:\n")
-        fkt <- names(sybil:::.SYBILenv[["purpose"]])
+        fkt <- names(.SYBILenv[["purpose"]])
         for(i in seq(along = fkt)) {
             cat(fkt[i], ":\n", sep = "")
-            cat(paste(sybil:::.SYBILenv[["purpose"]][[fkt[i]]]), sep = ", ")
+            cat(paste(.SYBILenv[["purpose"]][[fkt[i]]]), sep = ", ")
             cat("\n\n")
         }
         cat("\n")
@@ -91,7 +91,7 @@ getsybilenv <- function(part) {
         printmethods()
         printptype()
         printpurpose()
-        #print(sybil:::.SYBILenv[["solverCtrlParm"]])
+        #print(.SYBILenv[["solverCtrlParm"]])
     }
     else {
         cmd <- paste("print", part, "()", sep = "")
